# Geometric-Primitives

It defines a geometric primitive for accomplishing 3D shape generation.

## Installation

You can choose one of three installation options.

* From PyPI repository

To install the released version in PyPI repository, command it.

```shell
$ pip install geometric_primitives
```

* From source code

To install `geometric_primitives` from source code, command it.

```shell
$ pip install .
```

* From source code (editable mode)

To use editable development mode, command it.

```shell
$ pip install -r requirements.txt
$ python setup.py develop
```

## Uninstallation

If you would like to uninstall `geometric_primitives`, command it.

```shell
$ pip uninstall geometric_primitives
```

## Related Projects

* [Combinatorial-3D-Shape-Generation](https://github.com/POSTECH-CVLab/Combinatorial-3D-Shape-Generation)

## Contributor
* [Jungtaek Kim](http://jungtaek.github.io) (POSTECH)

## Contact
* Jungtaek Kim: [jtkim@postech.ac.kr](mailto:jtkim@postech.ac.kr)

## License
[MIT License](LICENSE)
